{-# LANGUAGE DeriveGeneric #-}
{-# LANGUAGE DuplicateRecordFields #-}
{-# LANGUAGE NamedFieldPuns #-}
{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE RecordWildCards #-}
{-# LANGUAGE StrictData #-}
{-# LANGUAGE NoImplicitPrelude #-}
{-# OPTIONS_GHC -fno-warn-unused-imports #-}
{-# OPTIONS_GHC -fno-warn-unused-matches #-}

-- Derived from AWS service descriptions, licensed under Apache 2.0.

-- |
-- Module      : Amazonka.SageMaker.Types.AnnotationConsolidationConfig
-- Copyright   : (c) 2013-2023 Brendan Hay
-- License     : Mozilla Public License, v. 2.0.
-- Maintainer  : Brendan Hay
-- Stability   : auto-generated
-- Portability : non-portable (GHC extensions)
module Amazonka.SageMaker.Types.AnnotationConsolidationConfig where

import qualified Amazonka.Core as Core
import qualified Amazonka.Core.Lens.Internal as Lens
import qualified Amazonka.Data as Data
import qualified Amazonka.Prelude as Prelude

-- | Configures how labels are consolidated across human workers and
-- processes output data.
--
-- /See:/ 'newAnnotationConsolidationConfig' smart constructor.
data AnnotationConsolidationConfig = AnnotationConsolidationConfig'
  { -- | The Amazon Resource Name (ARN) of a Lambda function implements the logic
    -- for
    -- <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-annotation-consolidation.html annotation consolidation>
    -- and to process output data.
    --
    -- This parameter is required for all labeling jobs. For
    -- <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-task-types.html built-in task types>,
    -- use one of the following Amazon SageMaker Ground Truth Lambda function
    -- ARNs for @AnnotationConsolidationLambdaArn@. For custom labeling
    -- workflows, see
    -- <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-custom-templates-step3.html#sms-custom-templates-step3-postlambda Post-annotation Lambda>.
    --
    -- __Bounding box__ - Finds the most similar boxes from different workers
    -- based on the Jaccard index of the boxes.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-BoundingBox@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-BoundingBox@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-BoundingBox@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-BoundingBox@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-BoundingBox@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-BoundingBox@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-BoundingBox@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-BoundingBox@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-BoundingBox@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-BoundingBox@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-BoundingBox@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-BoundingBox@
    --
    -- __Image classification__ - Uses a variant of the Expectation
    -- Maximization approach to estimate the true class of an image based on
    -- annotations from individual workers.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-ImageMultiClass@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-ImageMultiClass@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-ImageMultiClass@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-ImageMultiClass@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-ImageMultiClass@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-ImageMultiClass@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-ImageMultiClass@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-ImageMultiClass@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-ImageMultiClass@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-ImageMultiClass@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-ImageMultiClass@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-ImageMultiClass@
    --
    -- __Multi-label image classification__ - Uses a variant of the Expectation
    -- Maximization approach to estimate the true classes of an image based on
    -- annotations from individual workers.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-ImageMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-ImageMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-ImageMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-ImageMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-ImageMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-ImageMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-ImageMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-ImageMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-ImageMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-ImageMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-ImageMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-ImageMultiClassMultiLabel@
    --
    -- __Semantic segmentation__ - Treats each pixel in an image as a
    -- multi-class classification and treats pixel annotations from workers as
    -- \"votes\" for the correct label.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-SemanticSegmentation@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-SemanticSegmentation@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-SemanticSegmentation@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-SemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-SemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-SemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-SemanticSegmentation@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-SemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-SemanticSegmentation@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-SemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-SemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-SemanticSegmentation@
    --
    -- __Text classification__ - Uses a variant of the Expectation Maximization
    -- approach to estimate the true class of text based on annotations from
    -- individual workers.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-TextMultiClass@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-TextMultiClass@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-TextMultiClass@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-TextMultiClass@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-TextMultiClass@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-TextMultiClass@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-TextMultiClass@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-TextMultiClass@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-TextMultiClass@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-TextMultiClass@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-TextMultiClass@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-TextMultiClass@
    --
    -- __Multi-label text classification__ - Uses a variant of the Expectation
    -- Maximization approach to estimate the true classes of text based on
    -- annotations from individual workers.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-TextMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-TextMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-TextMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-TextMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-TextMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-TextMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-TextMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-TextMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-TextMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-TextMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-TextMultiClassMultiLabel@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-TextMultiClassMultiLabel@
    --
    -- __Named entity recognition__ - Groups similar selections and calculates
    -- aggregate boundaries, resolving to most-assigned label.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-NamedEntityRecognition@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-NamedEntityRecognition@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-NamedEntityRecognition@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-NamedEntityRecognition@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-NamedEntityRecognition@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-NamedEntityRecognition@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-NamedEntityRecognition@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-NamedEntityRecognition@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-NamedEntityRecognition@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-NamedEntityRecognition@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-NamedEntityRecognition@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-NamedEntityRecognition@
    --
    -- __Video Classification__ - Use this task type when you need workers to
    -- classify videos using predefined labels that you specify. Workers are
    -- shown videos and are asked to choose one label for each video.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-VideoMultiClass@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-VideoMultiClass@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-VideoMultiClass@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-VideoMultiClass@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VideoMultiClass@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VideoMultiClass@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-VideoMultiClass@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-VideoMultiClass@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VideoMultiClass@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-VideoMultiClass@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VideoMultiClass@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-VideoMultiClass@
    --
    -- __Video Frame Object Detection__ - Use this task type to have workers
    -- identify and locate objects in a sequence of video frames (images
    -- extracted from a video) using bounding boxes. For example, you can use
    -- this task to ask workers to identify and localize various objects in a
    -- series of video frames, such as cars, bikes, and pedestrians.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-VideoObjectDetection@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-VideoObjectDetection@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-VideoObjectDetection@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-VideoObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VideoObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VideoObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-VideoObjectDetection@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-VideoObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VideoObjectDetection@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-VideoObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VideoObjectDetection@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-VideoObjectDetection@
    --
    -- __Video Frame Object Tracking__ - Use this task type to have workers
    -- track the movement of objects in a sequence of video frames (images
    -- extracted from a video) using bounding boxes. For example, you can use
    -- this task to ask workers to track the movement of objects, such as cars,
    -- bikes, and pedestrians.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-VideoObjectTracking@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-VideoObjectTracking@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-VideoObjectTracking@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-VideoObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VideoObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VideoObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-VideoObjectTracking@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-VideoObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VideoObjectTracking@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-VideoObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VideoObjectTracking@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-VideoObjectTracking@
    --
    -- __3D Point Cloud Object Detection__ - Use this task type when you want
    -- workers to classify objects in a 3D point cloud by drawing 3D cuboids
    -- around objects. For example, you can use this task type to ask workers
    -- to identify different types of objects in a point cloud, such as cars,
    -- bikes, and pedestrians.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-3DPointCloudObjectDetection@
    --
    -- __3D Point Cloud Object Tracking__ - Use this task type when you want
    -- workers to draw 3D cuboids around objects that appear in a sequence of
    -- 3D point cloud frames. For example, you can use this task type to ask
    -- workers to track the movement of vehicles across multiple point cloud
    -- frames.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-3DPointCloudObjectTracking@
    --
    -- __3D Point Cloud Semantic Segmentation__ - Use this task type when you
    -- want workers to create a point-level semantic segmentation masks by
    -- painting objects in a 3D point cloud using different colors where each
    -- color is assigned to one of the classes you specify.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-3DPointCloudSemanticSegmentation@
    --
    -- __Use the following ARNs for Label Verification and Adjustment Jobs__
    --
    -- Use label verification and adjustment jobs to review and adjust labels.
    -- To learn more, see
    -- <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-verification-data.html Verify and Adjust Labels>
    -- .
    --
    -- __Semantic Segmentation Adjustment__ - Treats each pixel in an image as
    -- a multi-class classification and treats pixel adjusted annotations from
    -- workers as \"votes\" for the correct label.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-AdjustmentSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-AdjustmentSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-AdjustmentSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-AdjustmentSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-AdjustmentSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-AdjustmentSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-AdjustmentSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-AdjustmentSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-AdjustmentSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-AdjustmentSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-AdjustmentSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-AdjustmentSemanticSegmentation@
    --
    -- __Semantic Segmentation Verification__ - Uses a variant of the
    -- Expectation Maximization approach to estimate the true class of
    -- verification judgment for semantic segmentation labels based on
    -- annotations from individual workers.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-VerificationSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-VerificationSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-VerificationSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-VerificationSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VerificationSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VerificationSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-VerificationSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-VerificationSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VerificationSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-VerificationSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VerificationSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-VerificationSemanticSegmentation@
    --
    -- __Bounding Box Adjustment__ - Finds the most similar boxes from
    -- different workers based on the Jaccard index of the adjusted
    -- annotations.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-AdjustmentBoundingBox@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-AdjustmentBoundingBox@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-AdjustmentBoundingBox@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-AdjustmentBoundingBox@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-AdjustmentBoundingBox@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-AdjustmentBoundingBox@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-AdjustmentBoundingBox@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-AdjustmentBoundingBox@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-AdjustmentBoundingBox@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-AdjustmentBoundingBox@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-AdjustmentBoundingBox@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-AdjustmentBoundingBox@
    --
    -- __Bounding Box Verification__ - Uses a variant of the Expectation
    -- Maximization approach to estimate the true class of verification
    -- judgement for bounding box labels based on annotations from individual
    -- workers.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-VerificationBoundingBox@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-VerificationBoundingBox@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-VerificationBoundingBox@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-VerificationBoundingBox@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VerificationBoundingBox@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VerificationBoundingBox@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-VerificationBoundingBox@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-VerificationBoundingBox@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VerificationBoundingBox@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-VerificationBoundingBox@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VerificationBoundingBox@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-VerificationBoundingBox@
    --
    -- __Video Frame Object Detection Adjustment__ - Use this task type when
    -- you want workers to adjust bounding boxes that workers have added to
    -- video frames to classify and localize objects in a sequence of video
    -- frames.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-AdjustmentVideoObjectDetection@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-AdjustmentVideoObjectDetection@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-AdjustmentVideoObjectDetection@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-AdjustmentVideoObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-AdjustmentVideoObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-AdjustmentVideoObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-AdjustmentVideoObjectDetection@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-AdjustmentVideoObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-AdjustmentVideoObjectDetection@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-AdjustmentVideoObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-AdjustmentVideoObjectDetection@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-AdjustmentVideoObjectDetection@
    --
    -- __Video Frame Object Tracking Adjustment__ - Use this task type when you
    -- want workers to adjust bounding boxes that workers have added to video
    -- frames to track object movement across a sequence of video frames.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-AdjustmentVideoObjectTracking@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-AdjustmentVideoObjectTracking@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-AdjustmentVideoObjectTracking@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-AdjustmentVideoObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-AdjustmentVideoObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-AdjustmentVideoObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-AdjustmentVideoObjectTracking@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-AdjustmentVideoObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-AdjustmentVideoObjectTracking@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-AdjustmentVideoObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-AdjustmentVideoObjectTracking@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-AdjustmentVideoObjectTracking@
    --
    -- __3D Point Cloud Object Detection Adjustment__ - Use this task type when
    -- you want workers to adjust 3D cuboids around objects in a 3D point
    -- cloud.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-Adjustment3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-Adjustment3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-Adjustment3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-Adjustment3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-Adjustment3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-Adjustment3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-Adjustment3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-Adjustment3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-Adjustment3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-Adjustment3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-Adjustment3DPointCloudObjectDetection@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-Adjustment3DPointCloudObjectDetection@
    --
    -- __3D Point Cloud Object Tracking Adjustment__ - Use this task type when
    -- you want workers to adjust 3D cuboids around objects that appear in a
    -- sequence of 3D point cloud frames.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-Adjustment3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-Adjustment3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-Adjustment3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-Adjustment3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-Adjustment3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-Adjustment3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-Adjustment3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-Adjustment3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-Adjustment3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-Adjustment3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-Adjustment3DPointCloudObjectTracking@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-Adjustment3DPointCloudObjectTracking@
    --
    -- __3D Point Cloud Semantic Segmentation Adjustment__ - Use this task type
    -- when you want workers to adjust a point-level semantic segmentation
    -- masks using a paint tool.
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
    --
    -- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
    annotationConsolidationLambdaArn :: Prelude.Text
  }
  deriving (Prelude.Eq, Prelude.Read, Prelude.Show, Prelude.Generic)

-- |
-- Create a value of 'AnnotationConsolidationConfig' with all optional fields omitted.
--
-- Use <https://hackage.haskell.org/package/generic-lens generic-lens> or <https://hackage.haskell.org/package/optics optics> to modify other optional fields.
--
-- The following record fields are available, with the corresponding lenses provided
-- for backwards compatibility:
--
-- 'annotationConsolidationLambdaArn', 'annotationConsolidationConfig_annotationConsolidationLambdaArn' - The Amazon Resource Name (ARN) of a Lambda function implements the logic
-- for
-- <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-annotation-consolidation.html annotation consolidation>
-- and to process output data.
--
-- This parameter is required for all labeling jobs. For
-- <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-task-types.html built-in task types>,
-- use one of the following Amazon SageMaker Ground Truth Lambda function
-- ARNs for @AnnotationConsolidationLambdaArn@. For custom labeling
-- workflows, see
-- <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-custom-templates-step3.html#sms-custom-templates-step3-postlambda Post-annotation Lambda>.
--
-- __Bounding box__ - Finds the most similar boxes from different workers
-- based on the Jaccard index of the boxes.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-BoundingBox@
--
-- __Image classification__ - Uses a variant of the Expectation
-- Maximization approach to estimate the true class of an image based on
-- annotations from individual workers.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-ImageMultiClass@
--
-- __Multi-label image classification__ - Uses a variant of the Expectation
-- Maximization approach to estimate the true classes of an image based on
-- annotations from individual workers.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-ImageMultiClassMultiLabel@
--
-- __Semantic segmentation__ - Treats each pixel in an image as a
-- multi-class classification and treats pixel annotations from workers as
-- \"votes\" for the correct label.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-SemanticSegmentation@
--
-- __Text classification__ - Uses a variant of the Expectation Maximization
-- approach to estimate the true class of text based on annotations from
-- individual workers.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-TextMultiClass@
--
-- __Multi-label text classification__ - Uses a variant of the Expectation
-- Maximization approach to estimate the true classes of text based on
-- annotations from individual workers.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-TextMultiClassMultiLabel@
--
-- __Named entity recognition__ - Groups similar selections and calculates
-- aggregate boundaries, resolving to most-assigned label.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-NamedEntityRecognition@
--
-- __Video Classification__ - Use this task type when you need workers to
-- classify videos using predefined labels that you specify. Workers are
-- shown videos and are asked to choose one label for each video.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-VideoMultiClass@
--
-- __Video Frame Object Detection__ - Use this task type to have workers
-- identify and locate objects in a sequence of video frames (images
-- extracted from a video) using bounding boxes. For example, you can use
-- this task to ask workers to identify and localize various objects in a
-- series of video frames, such as cars, bikes, and pedestrians.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-VideoObjectDetection@
--
-- __Video Frame Object Tracking__ - Use this task type to have workers
-- track the movement of objects in a sequence of video frames (images
-- extracted from a video) using bounding boxes. For example, you can use
-- this task to ask workers to track the movement of objects, such as cars,
-- bikes, and pedestrians.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-VideoObjectTracking@
--
-- __3D Point Cloud Object Detection__ - Use this task type when you want
-- workers to classify objects in a 3D point cloud by drawing 3D cuboids
-- around objects. For example, you can use this task type to ask workers
-- to identify different types of objects in a point cloud, such as cars,
-- bikes, and pedestrians.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-3DPointCloudObjectDetection@
--
-- __3D Point Cloud Object Tracking__ - Use this task type when you want
-- workers to draw 3D cuboids around objects that appear in a sequence of
-- 3D point cloud frames. For example, you can use this task type to ask
-- workers to track the movement of vehicles across multiple point cloud
-- frames.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-3DPointCloudObjectTracking@
--
-- __3D Point Cloud Semantic Segmentation__ - Use this task type when you
-- want workers to create a point-level semantic segmentation masks by
-- painting objects in a 3D point cloud using different colors where each
-- color is assigned to one of the classes you specify.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-3DPointCloudSemanticSegmentation@
--
-- __Use the following ARNs for Label Verification and Adjustment Jobs__
--
-- Use label verification and adjustment jobs to review and adjust labels.
-- To learn more, see
-- <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-verification-data.html Verify and Adjust Labels>
-- .
--
-- __Semantic Segmentation Adjustment__ - Treats each pixel in an image as
-- a multi-class classification and treats pixel adjusted annotations from
-- workers as \"votes\" for the correct label.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-AdjustmentSemanticSegmentation@
--
-- __Semantic Segmentation Verification__ - Uses a variant of the
-- Expectation Maximization approach to estimate the true class of
-- verification judgment for semantic segmentation labels based on
-- annotations from individual workers.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-VerificationSemanticSegmentation@
--
-- __Bounding Box Adjustment__ - Finds the most similar boxes from
-- different workers based on the Jaccard index of the adjusted
-- annotations.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-AdjustmentBoundingBox@
--
-- __Bounding Box Verification__ - Uses a variant of the Expectation
-- Maximization approach to estimate the true class of verification
-- judgement for bounding box labels based on annotations from individual
-- workers.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-VerificationBoundingBox@
--
-- __Video Frame Object Detection Adjustment__ - Use this task type when
-- you want workers to adjust bounding boxes that workers have added to
-- video frames to classify and localize objects in a sequence of video
-- frames.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-AdjustmentVideoObjectDetection@
--
-- __Video Frame Object Tracking Adjustment__ - Use this task type when you
-- want workers to adjust bounding boxes that workers have added to video
-- frames to track object movement across a sequence of video frames.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-AdjustmentVideoObjectTracking@
--
-- __3D Point Cloud Object Detection Adjustment__ - Use this task type when
-- you want workers to adjust 3D cuboids around objects in a 3D point
-- cloud.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- __3D Point Cloud Object Tracking Adjustment__ - Use this task type when
-- you want workers to adjust 3D cuboids around objects that appear in a
-- sequence of 3D point cloud frames.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- __3D Point Cloud Semantic Segmentation Adjustment__ - Use this task type
-- when you want workers to adjust a point-level semantic segmentation
-- masks using a paint tool.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
newAnnotationConsolidationConfig ::
  -- | 'annotationConsolidationLambdaArn'
  Prelude.Text ->
  AnnotationConsolidationConfig
newAnnotationConsolidationConfig
  pAnnotationConsolidationLambdaArn_ =
    AnnotationConsolidationConfig'
      { annotationConsolidationLambdaArn =
          pAnnotationConsolidationLambdaArn_
      }

-- | The Amazon Resource Name (ARN) of a Lambda function implements the logic
-- for
-- <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-annotation-consolidation.html annotation consolidation>
-- and to process output data.
--
-- This parameter is required for all labeling jobs. For
-- <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-task-types.html built-in task types>,
-- use one of the following Amazon SageMaker Ground Truth Lambda function
-- ARNs for @AnnotationConsolidationLambdaArn@. For custom labeling
-- workflows, see
-- <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-custom-templates-step3.html#sms-custom-templates-step3-postlambda Post-annotation Lambda>.
--
-- __Bounding box__ - Finds the most similar boxes from different workers
-- based on the Jaccard index of the boxes.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-BoundingBox@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-BoundingBox@
--
-- __Image classification__ - Uses a variant of the Expectation
-- Maximization approach to estimate the true class of an image based on
-- annotations from individual workers.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-ImageMultiClass@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-ImageMultiClass@
--
-- __Multi-label image classification__ - Uses a variant of the Expectation
-- Maximization approach to estimate the true classes of an image based on
-- annotations from individual workers.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-ImageMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-ImageMultiClassMultiLabel@
--
-- __Semantic segmentation__ - Treats each pixel in an image as a
-- multi-class classification and treats pixel annotations from workers as
-- \"votes\" for the correct label.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-SemanticSegmentation@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-SemanticSegmentation@
--
-- __Text classification__ - Uses a variant of the Expectation Maximization
-- approach to estimate the true class of text based on annotations from
-- individual workers.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-TextMultiClass@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-TextMultiClass@
--
-- __Multi-label text classification__ - Uses a variant of the Expectation
-- Maximization approach to estimate the true classes of text based on
-- annotations from individual workers.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-TextMultiClassMultiLabel@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-TextMultiClassMultiLabel@
--
-- __Named entity recognition__ - Groups similar selections and calculates
-- aggregate boundaries, resolving to most-assigned label.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-NamedEntityRecognition@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-NamedEntityRecognition@
--
-- __Video Classification__ - Use this task type when you need workers to
-- classify videos using predefined labels that you specify. Workers are
-- shown videos and are asked to choose one label for each video.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VideoMultiClass@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-VideoMultiClass@
--
-- __Video Frame Object Detection__ - Use this task type to have workers
-- identify and locate objects in a sequence of video frames (images
-- extracted from a video) using bounding boxes. For example, you can use
-- this task to ask workers to identify and localize various objects in a
-- series of video frames, such as cars, bikes, and pedestrians.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VideoObjectDetection@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-VideoObjectDetection@
--
-- __Video Frame Object Tracking__ - Use this task type to have workers
-- track the movement of objects in a sequence of video frames (images
-- extracted from a video) using bounding boxes. For example, you can use
-- this task to ask workers to track the movement of objects, such as cars,
-- bikes, and pedestrians.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VideoObjectTracking@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-VideoObjectTracking@
--
-- __3D Point Cloud Object Detection__ - Use this task type when you want
-- workers to classify objects in a 3D point cloud by drawing 3D cuboids
-- around objects. For example, you can use this task type to ask workers
-- to identify different types of objects in a point cloud, such as cars,
-- bikes, and pedestrians.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-3DPointCloudObjectDetection@
--
-- __3D Point Cloud Object Tracking__ - Use this task type when you want
-- workers to draw 3D cuboids around objects that appear in a sequence of
-- 3D point cloud frames. For example, you can use this task type to ask
-- workers to track the movement of vehicles across multiple point cloud
-- frames.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-3DPointCloudObjectTracking@
--
-- __3D Point Cloud Semantic Segmentation__ - Use this task type when you
-- want workers to create a point-level semantic segmentation masks by
-- painting objects in a 3D point cloud using different colors where each
-- color is assigned to one of the classes you specify.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-3DPointCloudSemanticSegmentation@
--
-- __Use the following ARNs for Label Verification and Adjustment Jobs__
--
-- Use label verification and adjustment jobs to review and adjust labels.
-- To learn more, see
-- <https://docs.aws.amazon.com/sagemaker/latest/dg/sms-verification-data.html Verify and Adjust Labels>
-- .
--
-- __Semantic Segmentation Adjustment__ - Treats each pixel in an image as
-- a multi-class classification and treats pixel adjusted annotations from
-- workers as \"votes\" for the correct label.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-AdjustmentSemanticSegmentation@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-AdjustmentSemanticSegmentation@
--
-- __Semantic Segmentation Verification__ - Uses a variant of the
-- Expectation Maximization approach to estimate the true class of
-- verification judgment for semantic segmentation labels based on
-- annotations from individual workers.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VerificationSemanticSegmentation@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-VerificationSemanticSegmentation@
--
-- __Bounding Box Adjustment__ - Finds the most similar boxes from
-- different workers based on the Jaccard index of the adjusted
-- annotations.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-AdjustmentBoundingBox@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-AdjustmentBoundingBox@
--
-- __Bounding Box Verification__ - Uses a variant of the Expectation
-- Maximization approach to estimate the true class of verification
-- judgement for bounding box labels based on annotations from individual
-- workers.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-VerificationBoundingBox@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-VerificationBoundingBox@
--
-- __Video Frame Object Detection Adjustment__ - Use this task type when
-- you want workers to adjust bounding boxes that workers have added to
-- video frames to classify and localize objects in a sequence of video
-- frames.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-AdjustmentVideoObjectDetection@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-AdjustmentVideoObjectDetection@
--
-- __Video Frame Object Tracking Adjustment__ - Use this task type when you
-- want workers to adjust bounding boxes that workers have added to video
-- frames to track object movement across a sequence of video frames.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-AdjustmentVideoObjectTracking@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-AdjustmentVideoObjectTracking@
--
-- __3D Point Cloud Object Detection Adjustment__ - Use this task type when
-- you want workers to adjust 3D cuboids around objects in a 3D point
-- cloud.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-Adjustment3DPointCloudObjectDetection@
--
-- __3D Point Cloud Object Tracking Adjustment__ - Use this task type when
-- you want workers to adjust 3D cuboids around objects that appear in a
-- sequence of 3D point cloud frames.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-Adjustment3DPointCloudObjectTracking@
--
-- __3D Point Cloud Semantic Segmentation Adjustment__ - Use this task type
-- when you want workers to adjust a point-level semantic segmentation
-- masks using a paint tool.
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:us-east-1:432418664414:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:us-east-2:266458841044:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:us-west-2:081040173940:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-1:568282634449:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-1:477331159723:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-2:454466003867:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-south-1:565803892007:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-central-1:203001061592:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-northeast-2:845288260483:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:eu-west-2:487402164563:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ap-southeast-1:377565633583:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
--
-- -   @arn:aws:lambda:ca-central-1:918755190332:function:ACS-Adjustment3DPointCloudSemanticSegmentation@
annotationConsolidationConfig_annotationConsolidationLambdaArn :: Lens.Lens' AnnotationConsolidationConfig Prelude.Text
annotationConsolidationConfig_annotationConsolidationLambdaArn = Lens.lens (\AnnotationConsolidationConfig' {annotationConsolidationLambdaArn} -> annotationConsolidationLambdaArn) (\s@AnnotationConsolidationConfig' {} a -> s {annotationConsolidationLambdaArn = a} :: AnnotationConsolidationConfig)

instance Data.FromJSON AnnotationConsolidationConfig where
  parseJSON =
    Data.withObject
      "AnnotationConsolidationConfig"
      ( \x ->
          AnnotationConsolidationConfig'
            Prelude.<$> (x Data..: "AnnotationConsolidationLambdaArn")
      )

instance
  Prelude.Hashable
    AnnotationConsolidationConfig
  where
  hashWithSalt _salt AnnotationConsolidationConfig' {..} =
    _salt
      `Prelude.hashWithSalt` annotationConsolidationLambdaArn

instance Prelude.NFData AnnotationConsolidationConfig where
  rnf AnnotationConsolidationConfig' {..} =
    Prelude.rnf annotationConsolidationLambdaArn

instance Data.ToJSON AnnotationConsolidationConfig where
  toJSON AnnotationConsolidationConfig' {..} =
    Data.object
      ( Prelude.catMaybes
          [ Prelude.Just
              ( "AnnotationConsolidationLambdaArn"
                  Data..= annotationConsolidationLambdaArn
              )
          ]
      )
